Skip to contents

Plot Method for an Object of Class varmxid

Usage

# S3 method for class 'varmxid'
plot(
  x,
  level = 0.95,
  mu = TRUE,
  alpha = TRUE,
  beta = TRUE,
  nu = TRUE,
  psi = TRUE,
  theta = TRUE,
  robust = FALSE,
  drop = NULL,
  ncores = NULL,
  ...
)

Arguments

x

Object of class varmxid.

level

the confidence level required.

mu

Logical. If mu = TRUE, include estimates of the mu vector, if available. If mu = FALSE, exclude estimates of the mu vector.

alpha

Logical. If alpha = TRUE, include estimates of the alpha vector, if available. If alpha = FALSE, exclude estimates of the alpha vector.

beta

Logical. If beta = TRUE, include estimates of the beta matrix, if available. If beta = FALSE, exclude estimates of the beta matrix.

nu

Logical. If nu = TRUE, include estimates of the nu vector, if available. If nu = FALSE, exclude estimates of the nu vector.

psi

Logical. If psi = TRUE, include estimates of the psi matrix, if available. If psi = FALSE, exclude estimates of the psi matrix.

theta

Logical. If theta = TRUE, include estimates of the theta matrix, if available. If theta = FALSE, exclude estimates of the theta matrix.

robust

Logical. If TRUE, use robust (sandwich) sampling variance-covariance matrix. If FALSE, use normal theory sampling variance-covariance matrix.

drop

Optional vector of unique IDs to drop.

ncores

Positive integer. Number of cores to use.

...

additional arguments.

Value

Displays plots of point estimates and confidence intervals.

Author

Ivan Jacob Agaloos Pesigan